Keen | Profile
Description: User profile overview

# Customer Relationship Management

New Order

### Profile

Reports
Luke Davids Web Developer

### Important Update

Now
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s.
Take Action Dismiss

### Daily Salles

CSV
Chris Bent
SUV Themes Carp
$ 830
Ashley Stock
Merscedes Benz AMGww
$ 675
Jimmy Yesuku
All Nippon United Airlines
$ 194
Amanda West
Comboy Westem Limited
$ 65
Nick Holms
UILab Inc
$ 65

### Sales Statistics

Author
Customer
Announcements
Keen Admin Launch Day
To start a blog, think of a topic about and first brainstorm party is ways to write details
07 OCT, 2018
View
Incredibly Positive Reviews
To start a blog, think of a topic about and first brainstorm party is ways to write details
17 NOV, 2018
View
Award Winning Theme
To start a blog, think of a topic about and first brainstorm party is ways to write details
03 SEP, 2018
View
Projects
Keen Admin Launch Day
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
78%
First Milestone Achivement
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
55%
Reached 50,000 sales
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
24%
Today's Schedule
Octa Pre-Launch Meeting
9:20AM - 10:00AM
490 E Main St. Norwich...
View Map
UI/UX Design Updates
11:15AM - 12:30PM
246 R St. Manhattan NY...
View Map
Sales Report Summary Meet-up
4:30PM - 5:30PM
492 F Sub St. Norwich CT...
View Map

### Top Products

HTML 5 Templates
Font-end,Admin & Email
+79%
Wordpress Themes
eCommerce Website, Plugin
+21%
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
UI/UX Design
Evrything you ever imagine
+4%
Freebie Themes
Font-end & Admin
+34
UI/UX Design
Evrything you ever imagine
+4%
HTML 5 Templates
Font-end,Admin & Email
+79%
Wordpress Themes
eCommerce Website, Plugin
+21%
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
Freebie Themes
Font-end & Admin
+34
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
UI/UX Design
Evrything you ever imagine
+4%
Latest Trends
eCommerce Website, Plugin
+34%
HTML 5 Templates
Font-end,Admin & Email
+79%
Freebie Themes
Font-end & Admin
+34

### Work Progress

Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report
Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report

### Latest Tasks

Management meeting
09:30 AM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
NYCS internal discussion
03: 00 PM
Project Launch
11: 00 AM
Server maintenance
4: 30 PM
Export Navitare booking table
01:20 PM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
Replace datatables rows color
12:00 AM
NYCS internal discussion
03: 00 PM
Management meeting
09:30 AM
NYCS internal discussion
03: 00 PM
Replace datatables rows color
12:00 AM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
Export Navitare booking table
01:20 PM
Management meeting
09:30 AM

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!